<?php
/** Komi-Permyak (Перем Коми)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Enye Lav
 * @author Yufereff
 */

$fallback = 'ru';

$messages = array(
'underline-always' => 'Пыр',
'underline-never'  => 'Некöр',

# Dates
'sunday'        => 'Кресення',
'monday'        => 'Вильлун',
'tuesday'       => 'Торник',
'wednesday'     => 'Шöрлун',
'thursday'      => 'Четверг',
'friday'        => 'Пекнича',
'saturday'      => 'Субöта',
'sun'           => 'Кс',
'mon'           => 'Вл',
'tue'           => 'Вт',
'wed'           => 'Шл',
'thu'           => 'Чт',
'fri'           => 'Пк',
'sat'           => 'Сб',
'january'       => 'Январ',
'february'      => 'Февраль',
'march'         => 'Март',
'april'         => 'Апрель',
'may_long'      => 'Май',
'june'          => 'Юнь',
'july'          => 'Юль',
'august'        => 'Август',
'september'     => 'Сентяб',
'october'       => 'Октяб',
'november'      => 'Нояб',
'december'      => 'Декаб',
'january-gen'   => 'январ',
'february-gen'  => 'февраль',
'march-gen'     => 'март',
'april-gen'     => 'апрель',
'may-gen'       => 'май',
'june-gen'      => 'юнь',
'july-gen'      => 'юль',
'august-gen'    => 'август',
'september-gen' => 'сентяб',
'october-gen'   => 'октяб',
'november-gen'  => 'нояб',
'december-gen'  => 'декаб',
'jan'           => 'янв',
'feb'           => 'фев',
'mar'           => 'мар',
'apr'           => 'апр',
'may'           => 'май',
'jun'           => 'юнь',
'jul'           => 'юль',
'aug'           => 'авг',
'sep'           => 'сен',
'oct'           => 'окт',
'nov'           => 'ноя',
'dec'           => 'дек',

# Categories related messages
'pagecategories'                => '{{PLURAL:$1|Категория|Категория}}',
'category_header'               => '"$1" категорияын листбоккез',
'subcategories'                 => 'Поснитжык категорияэз',
'category-media-header'         => '"$1" категорияись файллэз',
'category-empty'                => 'Этiя категорияын öнi нем абу',
'hidden-categories'             => '{{PLURAL:$1|Сайöвтöм категория|Сайöвтöм категорияэз}}',
'hidden-category-category'      => 'Сайöвтöм категорияэз',
'category-subcat-count'         => '{{PLURAL:$2|Этiя категорияын дзир öтiк субкатегория.|{{PLURAL:$1|Мыччалöма $1 субкатегория}}  $2-ись.}}',
'category-subcat-count-limited' => 'Этiя категорияын {{PLURAL:$1|$1 субкатегория|$1 субкатегория|$1 субкатегория}}',
'category-article-count'        => '{{PLURAL:$2|Этiя категорияын дзир öтiк листбок.|{{PLURAL:$1|Мыччалöма этiя категорияись $1 листбок}}  $2-сис.}}',
'category-file-count-limited'   => 'Этiя категорияын {{PLURAL:$1|$1 файл|$1 файл|$1 файл}}.',
'listingcontinuesabbrev'        => '(одзлань)',

'about'         => 'Сы йылiсь',
'article'       => 'Гижöт',
'newwindow'     => '(виль öшынокын)',
'cancel'        => 'Керсьыны бöр',
'moredotdotdot' => 'Унажык...',
'mypage'        => 'Менам листбок',
'mytalk'        => 'Сёрнитанiнö',
'navigation'    => 'Уялöм',
'and'           => '&#32;да',

# Cologne Blue skin
'qbfind'         => 'Кошшан',
'qbbrowse'       => 'Мыччавны',
'qbedit'         => 'Мöдкодьсьöтны',
'qbpageoptions'  => 'Этiя листбок',
'qbmyoptions'    => 'Листбоккезö',
'qbspecialpages' => 'Тодильнöй листбоккез',
'faq'            => 'Отир сё юасьö',
'faqpage'        => 'Project:отир сё юасьö',

# Vector skin
'vector-action-delete' => 'Чышкыны',
'vector-view-view'     => 'Лыддьöтны',
'variants'             => 'Варианттэз',

'errorpagetitle'   => 'Сорасьöм',
'returnto'         => 'Бертны $1-öдз.',
'tagline'          => 'Босьтöм {{SITENAME}} вылiсь',
'help'             => 'Отсöт',
'search'           => 'Кошшан',
'searchbutton'     => 'Адззыны',
'go'               => 'Осьтны',
'searcharticle'    => 'Осьтны',
'history'          => 'Чулалöм',
'history_short'    => 'Чулалöм',
'printableversion' => 'Печатайтан версия',
'permalink'        => 'Пырся ыстöт',
'edit'             => 'Веськöтны',
'create'           => 'Лöсьöтны',
'editthispage'     => 'Мöдкодьсьöтны этiйö листбоксö',
'create-this-page' => 'Аркмöтны этiйö листбоксö',
'delete'           => 'Чышкыны',
'deletethispage'   => 'Чышкыны этiйö листбоксö',
'protect'          => 'Дорйыны',
'protect_change'   => 'мöдкодьсьöтны',
'newpage'          => 'Виль листбок',
'talkpage'         => 'Сёрнитны этiя листбок йылiсь',
'talkpagelinktext' => 'Сёрнитан',
'specialpage'      => 'Тодильнöй листбок',
'personaltools'    => 'Аслат керöтаннэз',
'postcomment'      => 'Виль юкöт',
'talk'             => 'Сёрни',
'views'            => 'Видзöтöммез',
'toolbox'          => 'Керöтаннэз',
'otherlanguages'   => 'Мöдiк кыввез вылын',
'redirectedfrom'   => '(Вештöм татчö  $1 вылiсь)',
'redirectpagesub'  => 'Мöдлаö иньдöтан листбок',
'lastmodifiedat'   => 'Листбокыс медбöрьяись вильмöтöм $1, $2.',
'jumpto'           => 'Вешшыны татчö:',
'jumptonavigation' => 'уялöм',
'jumptosearch'     => 'кошшан',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => '{{SITENAME}} йылiсь',
'aboutpage'            => 'Project:сы йылiсь',
'copyright'            => 'Быдöс этiйö позьö копируйтны $1 сьöртi.',
'copyrightpage'        => '{{ns:project}}:Копирайт',
'currentevents'        => 'Чулалан лоöмторрез',
'currentevents-url'    => 'Project:Чулалан лоöмторрез',
'disclaimers'          => 'Мийö сöстöмöсь йöз одзын',
'disclaimerpage'       => 'Project:Мийö сöстöмöсь йöз одзын',
'edithelp'             => 'Уджкерись понда отсöт',
'edithelppage'         => 'Help:Уджкерись понда отсöт',
'helppage'             => 'Help:Отсöт',
'mainpage'             => 'Пондöтчан листбок',
'mainpage-description' => 'Пондöтчан листбок',
'privacy'              => 'Астор дорьян йылiсь',
'privacypage'          => 'Project:Астор дорьян йылiсь',

'badaccess' => 'Пырикö сорасьöм',

'retrievedfrom'           => 'Öшмöс "$1"',
'youhavenewmessages'      => 'Тэныт локтiс $1 ($2).',
'newmessageslink'         => 'виль юöррез',
'newmessagesdifflink'     => 'медбöрьяись вильмöтöм',
'youhavenewmessagesmulti' => '$1 юкöтын тэ понда мыйкö эм',
'editsection'             => 'мöдкодьсьöтны',
'editold'                 => 'мöдкодьсьöтны',
'viewsourceold'           => 'Видзöтны öшмöс',
'editlink'                => 'мöдкодьсьöтны',
'viewsourcelink'          => 'видзöтны öшмöс',
'editsectionhint'         => 'Веськöтны юкöт: $1',
'toc'                     => 'Пышкöс',
'showtoc'                 => 'мыччавны',
'hidetoc'                 => 'сайöвтны',
'site-rss-feed'           => '$1 RSS-визыв',
'site-atom-feed'          => '$1 Atom-визыв',
'page-rss-feed'           => '«$1» — RSS-визыв',
'page-atom-feed'          => '«$1» — Atom-визыв',
'red-link-title'          => '$1 (листбокыс абу на)',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'     => 'Листбок',
'nstab-user'     => 'Уджкерисьлöн листбок',
'nstab-special'  => 'Тодильнöй листбок',
'nstab-project'  => 'Проект йылiсь',
'nstab-image'    => 'Серпас',
'nstab-template' => 'Шаблон',
'nstab-help'     => 'Отсасян',
'nstab-category' => 'Категория',

# General errors
'error'              => 'Сорасьöм',
'missing-article'    => 'Мыччöт чукöрись эз шед сiя листбок, кöда сэтчин вöлi "$1" $2 ним увтын. Этадз аркмывлö унажыксö сэк, кöр вешшан бы важмöм ыстöт пыр сэтшöм листбок вылö, кöда вöлi вештöм.  Абу кö сiдз, наттьö программаын мыйкö нетырви керöм. Юöрт жö сы йылiсь миянлö татчö: [[Special:ListUsers/sysop|administrator]],  сы дырни эн вунöт пасйыны URL.',
'missingarticle-rev' => '(версия#: $1)',
'internalerror'      => 'Пытшкас сорасьöм',
'internalerror_info' => 'Пытшкас сорасьöм: $1',
'badtitletext'       => 'Кошшана листбок нимыс абу веськыт, тыртöм, либо соралiн кыввезколасся нето интервики ним. А натьтö нимын эмöсь нелэдзан пассэз.',
'viewsource'         => 'Öшмöс мыччалан',

# Virus scanner
'virus-unknownscanner' => 'тöдтöм антивирус:',

# Login and logout pages
'yourname'                => 'Уджкерисьлöн пыран ним:',
'yourpassword'            => 'Пароль:',
'yourpasswordagain'       => 'Мöдпöвсьöтны пароль',
'remembermypassword'      => 'Видзны менчим пыран ним этiя компьютер тöдвылын (не дыржык {{PLURAL:$1| лунся|лунся}})',
'login'                   => 'Пырны ним увтын',
'nav-login-createaccount' => 'Пыран / гижöтчан',
'userlogin'               => 'Висьтасьны нето гижöтчыны',
'userloginnocreate'       => 'Пырны ним увтын',
'logout'                  => 'Сайласьны',
'userlogout'              => 'Петан',
'nologinlink'             => 'Кер аслыт уджкерисьлiсь ним',
'createaccount'           => 'Лöсьöт аслыт уджкерисьлiсь ним',
'gotaccountlink'          => 'Пырны ним увтын',
'createaccountmail'       => 'Электрон поштаöн',
'createaccountreason'     => 'Мыля:',
'loginerror'              => 'Пырöмыт эз аркмы',
'loginsuccesstitle'       => 'Пырöмыт аркмис',
'mailmypassword'          => 'Ыстыны виль пароль',
'loginlanguagelabel'      => 'Кыв: $1',

# Change password dialog
'resetpass'                 => 'Вежны пароль',
'oldpassword'               => 'Важ пароль',
'newpassword'               => 'Виль пароль',
'retypenew'                 => 'Мöдпöв гиж виль парольтö',
'resetpass_forbidden'       => 'Парольтö оз позь мöдкодьсьöтны',
'resetpass-submit-loggedin' => 'Вежны пароль',
'resetpass-submit-cancel'   => 'Керсьыны бöр',

# Edit page toolbar
'bold_sample'     => 'Кызкодя гижан',
'bold_tip'        => 'Кызкодь текст',
'italic_sample'   => 'Курсивöн гижан',
'italic_tip'      => 'Курсивöн гижан',
'link_sample'     => 'Ыстöтлöн юрним',
'link_tip'        => 'Вики пытшкся ыстöт',
'extlink_sample'  => 'http://www.example.com ыстöтлöн ним',
'extlink_tip'     => 'Вики сайö ыстöт (эн вунöт содтыны http:// )',
'headline_sample' => 'Юрнимлöн текст',
'headline_tip'    => 'Мöд тшупöта юрним',
'nowiki_sample'   => 'Пырт татчö форматируйттöм текст',
'nowiki_tip'      => 'Игнорируйтны вики-форматируйтöм',
'image_tip'       => 'Пыртöм файл',
'media_tip'       => 'Медиа-файл дынö ыстöт',
'sig_tip'         => 'Тэнат кырымпас да кад пас',
'hr_tip'          => 'Водса визь (видз сiйö шочыника)',

# Edit pages
'summary'                          => 'Мый вежöм:',
'subject'                          => 'Тема/юрним:',
'minoredit'                        => 'Татi невунка мöдкодьсьöтöм',
'watchthis'                        => 'Синмавны этiйö листбок',
'savearticle'                      => 'Вильмöтны листбок',
'preview'                          => 'Одзвыв нёджалан',
'showpreview'                      => 'Мыччавны мый аркмö',
'showdiff'                         => 'Неöткодьсö мыччалöм',
'anoneditwarning'                  => "'''Тöд''': Сiйöн,  мыля эн висьтась нимтö, этiя листбок историяö гижасö IP-адрестö.",
'summary-preview'                  => 'Дженыта сы йылiсь, мый лоас:',
'blockednoreason'                  => 'абу висьталöм мыля',
'loginreqtitle'                    => 'Колö пырны ним увтын',
'loginreqlink'                     => 'Пырны ним увтын',
'accmailtitle'                     => 'Пароль иньдöтöм',
'newarticle'                       => '(Виль)',
'newarticletext'                   => "Ыстöт кузя тэ шедiн листбок вылö,  кöдa абу на. Мед аркмöтны сiйö,  гиж тексттö улiсь öшынöко (унажык  видзöт: [[{{MediaWiki:Helppage}}|отсасян листбок]]). Шедiн кö татчö сорасьöмöн,  нырышт браузерсит '''бöрлань''' личкöт.",
'noarticletext'                    => 'Öнi этiя листбок вылын текстыс абу. 
Но  [[Special:Search/{{PAGENAME}}|сы ним]] казьтывсьö мöдiк листбоккез вылын, <span class="plainlinks">[{{fullurl:{{#Special:Log}}|page={{urlencode:{{FULLPAGENAME}}}}}} кошшыны лöсялана гижöттэз], нето [{{fullurl:{{FULLPAGENAME}}|action=edit}} кутчисьны этiя листбок бердö]</span>.',
'previewnote'                      => "'''Эта дзир одзвыв нёджалан, листбокыт абу на вильмöтöм!'''",
'editing'                          => 'Редактируйтöм $1',
'editingsection'                   => '$1 (юкöт) редактируйтöм',
'yourtext'                         => 'Текстыт',
'yourdiff'                         => 'Неöткодьыс',
'copyrightwarning'                 => "Тöд: текстас быдöс содтöттэз нето мöдкодьсьöтöммез  йöзöтсьöны лэдзöг $2 под вылын (видзöт $1). Он ко мöд,  медбы тексттэтö унаöтлiсö нето мöдкодьсьöтлiсö йöзыс,  эн и пукты нiйö татчö.   <br /> Этася тэ кыв сетан миянлö,  ачым пö лоа авторöн пыртан содтöттэзлiсь, нето босьта пö нiйö öшмöсiсь, кöда оз öв пытшкöссö одзлань йöзöтöмись да мöдкодьсьöтöмись.  <br /> '''ЭН ПУКТЫ ЮАСЬТÖГ ТАТЧÖ  АВТОРЛÖ ПОЗЬÖМ СЬÖРТI ДОРЙÖМ МАТЕРИАЛЛЭЗ!'''",
'templatesused'                    => 'Этiя листбок вылiсь {{PLURAL:$1|шаблон|шаблоннэз}}:',
'templatesusedpreview'             => 'Одзвыв нёджалан листбок вылiсь {{PLURAL:$1|шаблон|шаблоннэз}}:',
'template-protected'               => '(дорйöм)',
'template-semiprotected'           => '(мымдакö дорйöм)',
'hiddencategories'                 => 'Этiя листбок пырö $1 {{PLURAL:$1|сайöвтöм категория|сайöвтöм категория|сайöвтöм категорияэз}} коласö:',
'permissionserrorstext-withaction' => 'Тэныт оз позь керны $2 то {{PLURAL:$1|мыля|мыля}}:',

# History pages
'viewpagelogs'           => 'Мыччавны журналлэз этiя листбок понда',
'currentrev'             => 'Медбöрья версия',
'currentrev-asof'        => 'Öння версия $1-ись кодь',
'revisionasof'           => 'Версия № $1',
'previousrevision'       => '← Важжык',
'nextrevision'           => 'Вильжык версия',
'currentrevisionlink'    => 'Öння версия',
'cur'                    => 'öння',
'last'                   => 'одзза',
'page_first'             => 'медодзза',
'page_last'              => 'медбöрья',
'histlegend'             => "Вежöртöтаннэз:  '''({{int:cur}})''' – мый неöткодьыс öння версиякöт; '''({{int:last}})''' – мый неöткодьыс одзжыкся версиякöт,  '''({{int:minoreditletter}})''' – невунка вежыштöм.",
'history-fieldset-title' => 'Видзöтны история',
'histfirst'              => 'Медважся',
'histlast'               => 'Неважся',
'historyempty'           => '(прос)',

# Revision deletion
'rev-delundel'    => 'мыччавны/сайöвтны',
'rev-showdeleted' => 'мыччавны',
'revdel-restore'  => 'вежны тыдалöм',

# History merging
'mergehistory-reason' => 'Мыля:',

# Merge log
'revertmerge' => 'Торйöтны',

# Diffs
'history-title'           => '$1 вильмöтан история',
'difference'              => '(Неöткодьыс версияэз коласын)',
'difference-multipage'    => 'Неöткодьыс листбоккез коласын',
'lineno'                  => 'Визёк $1:',
'compareselectedversions' => 'Ордчаöтны бöрйöм версияэз',
'editundo'                => 'керны важмоз',

# Search results
'searchresults'                  => 'Адззöм то мый:',
'searchresults-title'            => '"$1" сьöртi адззöм то мый:',
'searchresulttext'               => 'Унажык информация {{SITENAME}} кошшикö, видзöт [[{{MediaWiki:Helppage}}|{{int:help}}]] вылö.',
'searchsubtitle'                 => 'Тэ кошшан \'\'\'[[:$1]]\'\'\' ([[Special:Prefixindex/$1|быдöс листбоккез, кöдна пондöтчöны "$1"-öн]]{{int:pipe-separator}}[[Special:WhatLinksHere/$1|быдöс листбоккез, кöдна ыстiсьöны "$1" вылö]])',
'searchsubtitleinvalid'          => '«$1» кошшикö',
'notitlematches'                 => 'Листбоккез ниммезын абу öткодь торрез',
'notextmatches'                  => 'Листбоккез тексттэзын абу öткодь торрез',
'prevn'                          => '{{PLURAL:$1|одзжыкся $1}}',
'nextn'                          => '{{PLURAL:$1|одзланься $1}}',
'viewprevnext'                   => 'Видзöтны ($1 {{int:pipe-separator}} $2) ($3)',
'searchprofile-everything'       => 'Быдлаись',
'searchprofile-articles-tooltip' => 'Кошшан $1ын',
'searchprofile-project-tooltip'  => 'Кошшан $1ын',
'search-result-size'             => '$1 ({{PLURAL:$2|1 кыв|$2 кыв}})',
'search-redirect'                => '(иньдöтöм $1 вылiсь)',
'search-section'                 => '(юкöт № $1)',
'search-suggest'                 => 'Поди  колö $1',
'search-interwiki-caption'       => 'Вачкисян проекттэз',
'search-interwiki-default'       => '$1 результат:',
'search-interwiki-more'          => '(унажык)',
'search-mwsuggest-enabled'       => 'öтсöттэзöн',
'search-mwsuggest-disabled'      => 'öтсöттэзтöг',
'searchall'                      => 'быдöс',
'nonefound'                      => "'''Пасйöт.''' Он кö нагладь шуан,  кытiсь кошшыны,  шедасö не быдöс тексттэз, кытöн пантасьö колан кылыс. Мед кошшыны быдöс тексттэзiсь (уджкериссез листбоккезiсь,  шаболоннэзiсь дмд.), гиж ''all:'',  нето утлянно мыччав,  кытiсь кошшыны.",
'powersearch'                    => 'Паськытжыка кошшан',
'powersearch-legend'             => 'Паськытжыка кошшан',
'powersearch-ns'                 => 'Ним чукöррезiсь кошшан:',
'powersearch-redir'              => 'Мöдлаö иньдöтöммез ним сьöртi',
'powersearch-field'              => 'Кошшан',
'powersearch-toggleall'          => 'Быдöс',
'powersearch-togglenone'         => 'Нем',

# Preferences page
'preferences'               => 'Лöсьöтаннэз',
'mypreferences'             => 'Лöсьöтаннэзö',
'timezoneregion-africa'     => 'Африка',
'timezoneregion-america'    => 'Америка',
'timezoneregion-antarctica' => 'Антарктика',
'timezoneregion-arctic'     => 'Арктика',
'timezoneregion-asia'       => 'Азия',
'timezoneregion-atlantic'   => 'Атлантика',
'timezoneregion-australia'  => 'Австралия',
'timezoneregion-europe'     => 'Европа',
'timezoneregion-indian'     => 'Индика океан',
'timezoneregion-pacific'    => 'Лöнь океан',
'youremail'                 => 'Электрон пошта:',
'username'                  => 'Уджкерисьлöн ним:',
'uid'                       => 'Уджкерисьлöн лыддьöса пас:',
'yourrealname'              => 'Быльнöй нимыт:',
'yourlanguage'              => 'Кыв:',
'yournick'                  => 'Виль кырымпас:',
'badsiglength'              => 'Кырымпасыт кузьöв.
Сылö оз туй лоны $1 {{PLURAL:$1|шыпасся|шыпасся}} кузьжык.',
'gender-unknown'            => 'Мыччавтöм',
'gender-male'               => 'Айка',
'gender-female'             => 'Инька',
'prefs-help-email-required' => 'Колö сетны электрон адрестö.',

# Groups
'group-sysop' => 'Веськöтлiссез',
'group-all'   => '(быдöс)',

'grouppage-sysop' => '{{ns:project}}:Веськöтлiссез',

# User rights log
'rightslog' => 'Уджкерисьлö позяннэз сьöртi журнал',

# Associated actions - in the sentence "You do not have permission to X"
'action-edit' => 'мöдкодьсьöтны этiйö листбоксö',

# Recent changes
'nchanges'                       => '{{PLURAL:$1|вильмöтöм|вильмöтöм|вильмöтöм}}',
'recentchanges'                  => 'Медбöрья вильмöтöммез',
'recentchanges-legend'           => 'Медбöрья вильмöтöммез понда лöсьöтаннэз',
'recentchanges-feed-description' => 'Синмавны медбöрья вильмöтöммез этiя вики визылын.',
'rcnote'                         => "{{PLURAL:$1|Медбöрья '''$1''' вильмöтöм|Медбöрья '''$1''' вильмöтöм|Медбöрья'''$1''' вильмöтöм}} '''$2''' лун сьöрна, $5 $4  кежö.",
'rclistfrom'                     => 'Мыччавны вильмöтöмсö  $1-сянь',
'rcshowhideminor'                => '$1 невунка мöдкöдьсьöтыштöм',
'rcshowhidebots'                 => '$1 бот',
'rcshowhideliu'                  => 'Ас нимöн $1 уджкерись',
'rcshowhideanons'                => '$1 нимтöг уджкерись',
'rcshowhidemine'                 => 'аслам $1 мöдкодьсьöтöм',
'rclinks'                        => 'Мыччавны  медбöрья $1 вильмöтöмсö $2 лун дырнаись<br />$3',
'diff'                           => 'неöтк.',
'hist'                           => 'чулалöм',
'hide'                           => 'Сайöвтны',
'show'                           => 'Мыччавны',
'minoreditletter'                => 'невн.',
'newpageletter'                  => 'В',
'boteditletter'                  => 'б',
'rc-enhanced-expand'             => 'Мыччавны поснитторрез (колö JavaScript)',
'rc-enhanced-hide'               => 'Сайöвтны поснитторрез',

# Recent changes linked
'recentchangeslinked'         => 'Йитчана вежöммез',
'recentchangeslinked-title'   => '$1-кöт йитчан мöдкодьсьöтöммез',
'recentchangeslinked-summary' => "Этiя нимлёдз мыччалö неважся вильмöтöмез листбоккезын, кöдна вылö ыстiсьöны висьталöм листбок (нето висьталöм категорияö пыран листбок) вылiсь. Листбоккез, кöдна  [[Special:Watchlist|синмалан нимлёдзат]] '''кызöтöмöсь'''.",
'recentchangeslinked-page'    => 'Листбоклöн ним:',
'recentchangeslinked-to'      => 'Мыччавны мöдкодьсьöтöммез листбоккез вылын, кöдна асьныс ыстiсьöны этiя листбок вылö',

# Upload
'upload'        => 'Кышавны файл',
'uploadlogpage' => 'Тöбалöм сьöртi журнал',
'uploadedimage' => "тöбалiс ''[[$1]]''",

# File description page
'filehist'                  => 'Файллöн история',
'filehist-help'             => 'Нырышт дата/кад, мед адззыны, кытшöмöн сэк вöлi файлыс.',
'filehist-current'          => 'öння',
'filehist-datetime'         => 'Дата/Кад',
'filehist-thumb'            => 'Серпас',
'filehist-thumbtext'        => 'Серпас  $1’ версия понда',
'filehist-user'             => 'Уджкерись',
'filehist-dimensions'       => 'Ыжда',
'filehist-comment'          => 'Пасйöт',
'imagelinks'                => 'Файл дынö ыстöттэз',
'linkstoimage'              => '{{PLURAL:$1|Сэтшöм листбок|$1 Сэтшöм листбоккез}} ыстiсьö(ны) этiя файл вылö:',
'sharedupload'              => 'Этiя файл $1-ись да вермас овны и мöдiк проекттэзын',
'uploadnewversion-linktext' => 'Кышавны этiя файллiсь виль версия',

# Random page
'randompage' => 'Виччисьтöг шедöм листбок',

# Statistics
'statistics'              => 'Статистика',
'statistics-header-edits' => 'Вильмöтöм йылiсь статистика',
'statistics-pages'        => 'Листбоккез',

'brokenredirects-edit'   => 'мöдкодьсьöтны',
'brokenredirects-delete' => 'чышкыны',

# Miscellaneous special pages
'nbytes'            => '$1 {{PLURAL:$1|байт|байт}}',
'nmembers'          => '$1 {{PLURAL:$1|объект|объект|объект}}',
'prefixindex'       => 'Листбок ниммезлiсь пондöтчаннэз мыччалан',
'shortpages'        => 'Дженыт листбоккез',
'longpages'         => 'Кузь листбоккез',
'newpages'          => 'Виль листбоккез',
'newpages-username' => 'Уджкерись:',
'ancientpages'      => 'Медваж листбоккез',
'move'              => 'Вежны ним',
'movethispage'      => 'Вежны листбокыслiсь ним',
'pager-newer-n'     => '{{PLURAL:$1|вильжык 1|вильжык $1}}',
'pager-older-n'     => '{{PLURAL:$1|важжык 1|важжык $1}}',

# Book sources
'booksources'               => 'Небöггез-öшмöссэз',
'booksources-search-legend' => 'Небöг йылiсь юöррез кошшан',
'booksources-go'            => 'Кошшыны',

# Special:Log
'log' => 'Журналлэз',

# Special:AllPages
'allpages'       => 'Быдöс листбоккез',
'alphaindexline' => '$1-сянь $2-дынö',
'prevpage'       => 'Одзжыкся листбок ($1)',
'allpagesfrom'   => 'Мыччавны листбоккез, кöдна пондöтчöны сiдз:',
'allpagesto'     => 'Мыччавны листбоккез татшöмöдз:',
'allarticles'    => 'Быдöс листбоккез',
'allpagessubmit' => 'Керны',

# Special:Categories
'categories' => 'Категорияэз',

# Special:LinkSearch
'linksearch' => 'Вики сайöдз ыстöттэз',

# Special:Log/newusers
'newuserlogpage'          => 'Уджкерисьö гижöтчан журнал',
'newuserlog-create-entry' => 'Виль уджкерись',

# Special:ListGroupRights
'listgrouprights-members' => '(уджкериссезлöн нимлёдз)',

# E-mail user
'emailuser' => 'Этiя ужкерисьлö гижöт',
'emailfrom' => 'Кинсянь:',
'emailto'   => 'Кинлö:',

# Watchlist
'watchlist'         => 'Синмаланнэз',
'mywatchlist'       => 'Синмаланнэзö',
'addedwatchtext'    => '«[[:$1]]» листбок вöлi содтöм [[Special:Watchlist|синмалан нимлёдзат]].
Быдöс, мый пондас вежсьыны листбок вылас да сыкöт йитчöм сёрнитанын, позяс адзыны этiя нимлёдзись; сiя лоас сiдзжо кызжыка тöдчöтöм [[Special:RecentChanges|виль вежсьöммез сьöртi нимлёдзын]], медбы позис кокнитжыка казявны.',
'removedwatchtext'  => 'Листбок «[[:$1]]» вöлi вештöм [[Special:Watchlist|синмалан нимлёдзсит]].',
'watch'             => 'Синмав',
'watchthispage'     => 'Синмавны этiйö листбок',
'unwatch'           => 'Оз ков синмавны',
'unwatchthispage'   => 'Дугдыны синмавны',
'watchlist-details' => 'Синмалан нимлёдзат $1 {{PLURAL:$1|листбок|листбок|листбок}}, сёрнитан листбоккесö лыдö босьттöг.',
'wlshowlast'        => 'Мыччавны медбöрья $1 час $2 лун $3 понда',
'watchlist-options' => 'Синмалан нимлёз понда лöсьöтаннэз',

# Displayed when you click the "watch" button and it is in the process of watching
'watching'   => 'Синмавны …',
'unwatching' => 'Дугдыны синмавны …',

# Delete
'deletepage'            => 'Чышкыны листбок',
'delete-confirm'        => 'Чышкыны "$1"',
'delete-legend'         => 'Чышкыны',
'confirmdeletetext'     => 'Тэ мöдан быдсöн чышкыны листбок (нето серпас) да  сылiсь история. Былись я тэ мöдан сiйö керны,  вежöртан я бура, мыйö этö вермас вайöтны,  и керан я этiйö [[{{MediaWiki:Policy-url}}]] туйдöттэз сьöртi',
'actioncomplete'        => 'Керсьöм',
'deletedtext'           => '«$1» чышкöм. Видзöт $2-ись медбöрья чышкöммесö.',
'deletedarticle'        => 'чышкис "[[$1]]"',
'dellogpage'            => 'Шупкан чукöр',
'deletecomment'         => 'Мыля:',
'deleteotherreason'     => 'Эшö мыля чышкöм:',
'deletereasonotherlist' => 'Эшö мыля',

# Rollback
'rollbacklink' => 'вежны бöр',

# Protect
'protectlogpage'              => 'Дорьян журнал',
'protectedarticle'            => 'дорйöм "[[$1]]"',
'modifiedarticleprotection'   => "''[[$1]]'' листбоксö дорьян выныс мöдкодьсьöтöм",
'protectcomment'              => 'Мыля:',
'protectexpiry'               => 'Помасьö:',
'protect_expiry_invalid'      => 'Памасян кадыс соралöм',
'protect_expiry_old'          => 'Помасян кад — чулалöмын.',
'protect-text'                => "Татöн тэ верман видзöтны да вежны '''$1''' листбок понда дорьян тшупöт.",
'protect-locked-access'       => "Уджкерисьлöн нимыт оз тырмы, мед вежны листбокыслiсь дорьян тшупöт.
Öння лöсьöтаннэз '''$1''' листбок понда:",
'protect-cascadeon'           => 'Этiя листбокыс дорйöм, мыля сiя пыртöм улынжык висьталöм {{PLURAL:$1|листбокö|листбокö}}, кытчö лöсьöтöм каскад нёж дорьян.
Тэ верман вежны этiя листбоклiсь дорьян тшупöт, но каскад нёж дорьян сысянь оз вежсьы.',
'protect-default'             => 'Дорйытöм',
'protect-fallback'            => 'Колö мед лэдзис «$1»',
'protect-level-autoconfirmed' => 'Дорйыны виль да гижöтчытöм уджкериссез шогья',
'protect-level-sysop'         => 'Дзир веськöтлiссез понда',
'protect-summary-cascade'     => 'каскад нёж',
'protect-expiring'            => 'чулалас $1 (UTC) кежö',
'protect-cascade'             => 'Дорйыны листбоккез, кöдна пыртöмöсь этiя листбокö (каскад нёж дорьян)',
'protect-cantedit'            => 'Тэ он вермы вежны этiя листбоклiсь дорьян тшупöт, мыля тэныт оз позь сiйö мöдкодьсьöтны.',
'protect-othertime'           => 'Мöдiк кад:',
'protect-othertime-op'        => 'мöдiк кад',
'restriction-type'            => 'Позяннэз:',
'restriction-level'           => 'Падмöтан тшупöт:',
'minimum-size'                => 'Медпоснит ыжда',
'maximum-size'                => 'Медгырись ыжда:',

# Undelete
'undeletelink'     => 'видзöтны/керны важмоз',
'undeletecomment'  => 'Мыля:',
'undeletedarticle' => "бöр керис ''[[$1]]''",

# Namespace form on various pages
'namespace'      => 'Ниммез чукöр:',
'invert'         => 'Мöдöртны бöрйöмсö',
'blanknamespace' => '(Медколана)',

# Contributions
'contributions'       => 'Уджкерисьлöн пыртöм пай',
'contributions-title' => 'Уджкерись $1-лöн пыртöм пай',
'mycontris'           => 'Мый ме пыртi',
'contribsub2'         => '$1 ($2) пыртöм пай',
'uctop'               => '(медбöрья)',
'month'               => 'Тöлiсь сьöрна (и одзжык):',
'year'                => 'Во сьöрна (и одзжык):',

'sp-contributions-newbies'  => 'Мыччавны токö виль уджкериссезöн пыртöм пайез',
'sp-contributions-blocklog' => 'падмöтаннэз',
'sp-contributions-search'   => 'Пыртöм пай кошшан',
'sp-contributions-username' => 'IP-адрес нето уджкерисьлöн ним:',
'sp-contributions-submit'   => 'Кошшыны',

# What links here
'whatlinkshere'            => 'Ыстöттэз татчö',
'whatlinkshere-title'      => '"$1" вылö ыстiсян листбоккез',
'whatlinkshere-page'       => 'Листбок:',
'linkshere'                => "''[[:$1]]''' вылö ыстiсьöны эттшöм листбоккез:",
'isredirect'               => 'мöдлаö иньдöтан листбок',
'istemplate'               => 'пыртöм',
'isimage'                  => 'серпас вылö ыстiсян',
'whatlinkshere-prev'       => '{{PLURAL:$1|одзжыкся|одзжыкся|одзжыкся}} $1',
'whatlinkshere-next'       => '{{PLURAL:$1|одзланься|одзланься|одзланься}} $1',
'whatlinkshere-links'      => '← ыстöттэз',
'whatlinkshere-hideredirs' => 'мöдлаö иньдöтöммез $1-а',
'whatlinkshere-hidetrans'  => '"$1"  пыртöм',
'whatlinkshere-hidelinks'  => '$1 ыстöттэз',
'whatlinkshere-filters'    => 'Сысъяннэз',

# Block/unblock
'blockip'                  => 'Падмöтны',
'ipboptions'               => '2 час:2 hours,1 лун:1 day,3 лун:3 days,1 недель:1 week,2 недель:2 weeks,1 тöлiсь:1 month,3 тöлiсь:3 months,6 тöлiсь:6 months,1 во:1 year, пыр:infinite',
'ipblocklist'              => 'Падмöтöм IP-адрессэз да уджкериссезлöн ниммез',
'blocklink'                => 'падмöтны',
'unblocklink'              => 'вештыны падмöт',
'change-blocklink'         => 'мöдкодьсьöтны падмöт',
'contribslink'             => 'пуктöм',
'blocklogpage'             => 'Падмöтаннэз сьöртi журнал',
'blocklogentry'            => 'падмöтiс  [[$1]]-сö   $3 $2 -öдз',
'unblocklogentry'          => 'осьтiс падмöтсö $1 вылiсь',
'block-log-flags-nocreate' => 'виль уджкерисьöн лоны оз позь',

# Move page
'movepagetext'     => "Кöр улiсь форма сьöртi вежан нимсö листбокыслiсь, öтдырйи вештан мöдлаö и вильмöтöм сьöртi журналсö. Важ ним лоас иньдöтанöн виль ним дынö. Тэ верман автоматическöя вильмöтны нiйо иньдöтаннэсö, кöдна ыстiсö важ ним дынö. Он кö кер сiдз, видзöт жö [[Special:DoubleRedirects|кыкпöвса]] да [[Special:BrokenRedirects|орöтöм иньдöтöммесö]]. Тэ ачыт видзан кыв сы понда, медбы ыстöттэз и одзлань вайöтiсö, сэтчö, кытчö колö. Тöд, листбокыслöн нимыс оз вежсьы, кöр виль нима листбокыс эм ни, и сыкоста оз ло мöдлаö иньдöтанöн нето тыртöмöн, и сэтчин абу мöдкодьсьöтöммес . Сiдзкö тэ верман сетны листбокыслö ним, кöда сылöн öнтай вöлi, сорасин кö ним вежико, но тэ он вермы казявтöг чышкыны тыр листбок.
'''Тöд!'''
Ним вежöмыссянь вермасö лоны ыджыт и виччисьтöм мöдкодьсьöтöммез «йöзлы радейтана» листбоккез вылын.
Бура жö думайт сы вотодз, кыдз пондан мыйко керны, мый вермас этасянь аркмыны.",
'movepagetalktext' => 'Сы йылiсь сёрнитан сiдзжö керсяс виль нимаöн аспонадсис. Но кöр:
* Сэтшöм жö нима пондöтöм листбокыс эм ни, нето
* Абу сувтöтöмыт улiсьжык ыбкоддьöмо вожок, сэк ковсяс вештыны нето öтлаöтны листбоккесö  кипонiсь.',
'movearticle'      => 'Вежны листбокыслiсь ним:',
'newtitle'         => 'Виль ним:',
'move-watch'       => 'Пыртны этiйö листбоксö синмалöм понда нимлёдзö',
'movepagebtn'      => 'Вежны листбоклiсь ним',
'pagemovedsub'     => 'Листбоклöн нимыс вежöм',
'movepage-moved'   => "'''Листбоклiсь «$1» ним вежöм «$2»''' вылö",
'articleexists'    => 'Сэтшöм нимыс эм ни мöдiк листбоклöн, нето гижан бы непозян ним.
Борйы кытшöмкö мöд ним.',
'talkexists'       => "'''Листбоклiсь ним вежöм ни, а сы йылiсь сёрнитанлiсь абу, мыля сэтшöм жö нима листбок эм ни. Öтлаöт жö нiйö кипонiсь.'''",
'movedto'          => 'нымыс вежöм … вылö',
'movetalk'         => 'Вежны ним и сёрнитан листбокыслiсь',
'1movedto2'        => 'вежис  «[[$1]]»-лiсь нимсö «[[$2]]» вылö',
'1movedto2_redir'  => '«[[$1]]»-лö сетiсö виль ним «[[$2]]» мöдлаö иньдöтöм весьтын',
'movelogpage'      => 'Юрниммез вежöм йылiсь',
'movereason'       => 'Мыля:',
'revertmove'       => 'керны важмоз',

# Export
'export' => 'Гижöттэсö петкöтöм',

# Namespace 8 related
'allmessages-filter-all' => 'Быдöс',
'allmessages-language'   => 'Кыв:',

# Thumbnails
'thumbnail-more' => 'Ыждöтны',

# Tooltip help for the actions
'tooltip-pt-userpage'             => 'Аслат листбок',
'tooltip-pt-mytalk'               => 'Сёрнитан листбокыт',
'tooltip-pt-preferences'          => 'Тэнат лöсьöтаннэт',
'tooltip-pt-watchlist'            => 'Синмалан листбоккезö ним сьöртi',
'tooltip-pt-mycontris'            => 'Мый тэ мöдкодьсьöтiн, ним сьöртi',
'tooltip-pt-login'                => 'Татчö верман нимтö пыртны, но туйö и сiдз уджавны',
'tooltip-pt-logout'               => 'Петан',
'tooltip-ca-talk'                 => 'Этiя листбок йылiсь сёрни',
'tooltip-ca-edit'                 => 'Этiйö листбок позьö мöдкодьсьöтны. Сiйö вильмöттöдз нырышт «нёджöвт» личкöт вылö,  мед видзöтны, мый тэнат аркмö.',
'tooltip-ca-addsection'           => 'Лöсьöтны виль юкöт',
'tooltip-ca-viewsource'           => 'Этiйö листбок оз позь вильмöтны. Верман токö видзöтны да копируйтны сылiсь под текст',
'tooltip-ca-history'              => 'Кыдз вильмöтлiсö этiйö листбоксö',
'tooltip-ca-protect'              => 'Дорйыны этiйö листбоксö',
'tooltip-ca-delete'               => 'Чышкыны этiйö листбоксö',
'tooltip-ca-move'                 => 'Вежны листбоклiсь ним',
'tooltip-ca-watch'                => 'Содтыны листбок синмаланнэз коласö',
'tooltip-ca-unwatch'              => 'Шупкыны этiйö листбок синмаланнэз коласiсь',
'tooltip-search'                  => 'Кошшыны {{SITENAME}}',
'tooltip-search-go'               => 'Осьтны листбок, кöдалöн нимыс утлянно сэтшöм, эм кö сiя',
'tooltip-search-fulltext'         => 'Адззыны листбоккез, кытöн эм сэтшöм текст',
'tooltip-p-logo'                  => 'Пондöтчан листбок вылö',
'tooltip-n-mainpage'              => 'Вешшыны пондöтчан листбок вылö',
'tooltip-n-mainpage-description'  => 'Вешшыны пондöтчан листбок вылö',
'tooltip-n-portal'                => 'Проект йылiсь, мый тэ верман керны, кытiсь мый кошшыны',
'tooltip-n-currentevents'         => 'Адззыны унажык юöррез чулалан лоöмторрез йылiсь',
'tooltip-n-recentchanges'         => 'Медбöрья вежöммез',
'tooltip-n-randompage'            => 'Кышавны виччисьтöг шедöм листбок',
'tooltip-n-help'                  => 'Отсöт проект понда:',
'tooltip-t-whatlinkshere'         => 'Быдöс листбоккез, кöдна ыстiсьöны татчö',
'tooltip-t-recentchangeslinked'   => 'Медбöрья вильмöтöммез листбоккезын,  кöдна вылö этiя листбокыс ыстiсьö',
'tooltip-feed-rss'                => 'Этiя листбок понда RSS',
'tooltip-feed-atom'               => 'Этiя листбок понда Atom-визыв',
'tooltip-t-contributions'         => 'Видзöтны листбоккез, кöднö вильмöтлiс этiя уджкерись',
'tooltip-t-emailuser'             => 'Иньдöтны гижöт этiя уджкерисьлö',
'tooltip-t-upload'                => 'Кышавны медиа-файллэз',
'tooltip-t-specialpages'          => 'Тодильнöй листбоккез ним сьöртi',
'tooltip-t-print'                 => 'Этiя листбоклöн печатайтан версия',
'tooltip-t-permalink'             => 'Листбоклöн этiя версия дынö пырся ыстöт',
'tooltip-ca-nstab-main'           => 'Видзöт листбоклiсь пытшкöс',
'tooltip-ca-nstab-user'           => 'Видзöтны уджкерисьлiсь листбок',
'tooltip-ca-nstab-media'          => 'Медиа файл',
'tooltip-ca-nstab-special'        => 'Этiя листбокыс тодильнöй, сiйö оз позь мöдкодьсьöтны',
'tooltip-ca-nstab-project'        => 'Проектлöн листбок',
'tooltip-ca-nstab-image'          => 'Файллöн листбок',
'tooltip-ca-nstab-template'       => 'Шаблон видзан листбок',
'tooltip-ca-nstab-help'           => 'Отсасян листбок',
'tooltip-ca-nstab-category'       => 'Категория листбок',
'tooltip-minoredit'               => 'Пасйыны сiйö неыджыт мöдкодьсьöтöм туйö',
'tooltip-save'                    => 'Вильмöтны листбок',
'tooltip-preview'                 => 'Дзар кер,  листбоксö вильмöттöдззат,  мый тэнат аркмö!',
'tooltip-diff'                    => 'Мыччавны мый мöдкодьсьöтöма текстiсь.',
'tooltip-compareselectedversions' => 'Видзöтны, мый неöткодьыс этiя листбоклöн кык версия коласын',
'tooltip-watch'                   => 'Содтыны этiйö листбок синмаланнэз коласö',
'tooltip-rollback'                => 'Öтпыр нырыштöмöн чышкыны быдöс, мый керис медбöрья редактор',
'tooltip-undo'                    => '"Бöр вежны" чышкö öннясö да пыртö бöр одзжыкся редакция. Позьö висьтавны,  мыля сiйö вежин бöр.',

# Browsing diffs
'previousdiff' => '← Одзжыкся вильмöтöм',
'nextdiff'     => 'Сыбöрся вильмöтöтöм →',

# Media information
'file-info-size' => '$1 × $2 пиксел, файллöн ыжда: $3, MIME-тип: $4',
'file-nohires'   => '<small>Буржыка тыдалан версия абу.</small>',
'svg-long-desc'  => 'SVG-файл, гижöм сьöртi $1 × $2 пиксел,  файллöн ыжда: $3',
'show-big-image' => 'Буржыка тыдалан серпас',

# Bad image list
'bad_image_list' => 'Формат лöсьöтiкö видз тöд вылын: Уджавны пондасö токö нимлёдзись визёккез (кöдналöн пондöтчанын эм *). Визёклöн медодзза ыстöт ась лоö йитöм неуджалан файлкöт.  Мöдiк ыстöттэз сiя жö визёкын огö пыртö сы лыдö,  м.ш. гижöттэз, кытчö медиа-файл позьö пыртны.',

# Metadata
'metadata'          => 'Метадатаэз',
'metadata-help'     => 'Файлö кышасьöмöсь содтöт юöррез, кöдна аркмывлöны лыдпаса камераын нето сканерын. Редактируйтiсö кö файлсö аркмöтöм бöрын,  мукöд параметрыс оз понды сё ни лöсявны öння серпаскöт.',
'metadata-expand'   => 'Мыччавны содтöт юöррез',
'metadata-collapse' => 'Сайöвтны поснитжык деталлез',
'metadata-fields'   => 'EXIF метадатаэза ыббез, кöдна шуöмöсь нимлёдзын, лоасö сё ни мыччалöмöсь серпаса листбок вылын, мöдiккез лоасö, он кö шу мöднёж, сайöвтöмöсь:
* make
* model
* datetimeoriginal
* exposuretime
* fnumber
* isospeedratings
* focallength
* artist
* copyright
* imagedescription
* gpslatitude
* gpslongitude
* gpsaltitude',

# EXIF tags
'exif-imagewidth'  => 'Пасьта',
'exif-imagelength' => 'Вылына',

# External editor support
'edit-externally'      => 'Редактируйтны этiйö файлсö мöд программа пыр',
'edit-externally-help' => '(унажык видзöт: [//www.mediawiki.org/wiki/Manual:External_editors удж кежö лöсьöтны туйдöтан])',

# 'all' in various places, this might be different for inflected languages
'watchlistall2' => 'быдöс',
'namespacesall' => 'быдöс',
'monthsall'     => 'быдöс',
'limitall'      => 'быдöс',

# Watchlist editing tools
'watchlisttools-view' => 'Видзöт лöсялана вильмöтöммез',
'watchlisttools-edit' => 'Видзöтны/мöдкодьсьöтны нимлёдз',
'watchlisttools-raw'  => 'Нимлёдз пöртны текстö',

# Special:SpecialPages
'specialpages' => 'Тодильнöй листбоккез',

# HTML forms
'htmlform-selectorother-other' => 'Мöдiк',

);
